searchData={"items":[{"type":"module","title":"Anthropix","doc":"![Anthropix](https://raw.githubusercontent.com/lebrunel/anthropix/main/media/poster.webp)\n\n![License](https://img.shields.io/github/license/lebrunel/anthropix?color=informational)\n\nAnthropix is an open-source Elixir client for the Anthropic API, providing a\nsimple and convenient way to integrate Claude, Anthropic's powerful language\nmodel, into your applications.\n\n- ✅ API client fully implementing the [Anthropic API](https://docs.anthropic.com/claude/reference/getting-started-with-the-api)\n- 🛜 Streaming API requests\n  - Stream to an Enumerable\n  - Or stream messages to any Elixir process","ref":"Anthropix.html"},{"type":"module","title":"Installation - Anthropix","doc":"The package can be installed by adding `anthropix` to your list of\ndependencies in `mix.exs`.\n\n```elixir\ndef deps do\n  [\n    {:anthropix, \"~> 0.2.0\"}\n  ]\nend\n```","ref":"Anthropix.html#module-installation"},{"type":"module","title":"Quickstart - Anthropix","doc":"For more examples, refer to the [Anthropix documentation](https://hexdocs.pm/anthropix).\n\n#","ref":"Anthropix.html#module-quickstart"},{"type":"module","title":"Initiate a client. - Anthropix","doc":"See `Anthropix.init/2`.\n\n```elixir\niex> client = Anthropix.init(api_key)\n```\n\n#","ref":"Anthropix.html#module-initiate-a-client"},{"type":"module","title":"Chat with Claude - Anthropix","doc":"See `Anthropix.chat/2`.\n\n```elixir\niex> messages = [\n...>   %{role: \"user\", content: \"Why is the sky blue?\"},\n...>   %{role: \"assistant\", content: \"Due to rayleigh scattering.\"},\n...>   %{role: \"user\", content: \"How is that different than mie scattering?\"},\n...> ]\n\niex> Anthropix.chat(client, [\n...>   model: \"claude-3-opus-20240229\",\n...>   messages: messages,\n...> ])\n{:ok, %{\"content\" => [%{\n  \"type\" => \"text\",\n  \"text\" => \"Mie scattering affects all wavelengths similarly, while Rayleigh favors shorter ones.\"\n}], ...}}\n```\n\n#","ref":"Anthropix.html#module-chat-with-claude"},{"type":"module","title":"Streaming - Anthropix","doc":"A streaming request can be initiated by setting the `:stream` option.\n\nWhen `:stream` is true a lazy `t:Enumerable.t/0` is returned which can be used\nwith any `Stream` functions.\n\n```elixir\niex> {:ok, stream} = Anthropix.chat(client, [\n...>   model: \"claude-3-opus-20240229\",\n...>   messages: messages,\n...>   stream: true,\n...> ])\n{:ok, #Function<52.53678557/2 in Stream.resource/3>}\n\niex> stream\n...> |> Stream.each(&update_ui_with_chunk/1)\n...> |> Stream.run()\n:ok\n```\n\nBecause the above approach builds the `t:Enumerable.t/0` by calling `receive`,\nusing this approach inside GenServer callbacks may cause the GenServer to\nmisbehave. Setting the `:stream` option to a `t:pid/0` returns a `t:Task.t/0`\nwhich will send messages to the specified process.","ref":"Anthropix.html#module-streaming"},{"type":"function","title":"Anthropix.chat/2","doc":"Chat with Claude. Send a list of structured input messages with text and/or\nimage content, and Claude will generate the next message in the conversation.","ref":"Anthropix.html#chat/2"},{"type":"function","title":"Options - Anthropix.chat/2","doc":"* `:model` (`t:String.t/0`) - Required. The model that will complete your prompt.\n* `:messages` (list of `t:map/0`) - Required. Input messages.\n* `:system` (`t:String.t/0`) - System prompt.\n* `:max_tokens` (`t:integer/0`) - The maximum number of tokens to generate before stopping. The default value is `4096`.\n* `:metadata` (`t:map/0`) - A map describing metadata about the request.\n* `:stop_sequences` (list of `t:String.t/0`) - Custom text sequences that will cause the model to stop generating.\n* `:stream` - Whether to incrementally stream the response using server-sent events. The default value is `false`.\n* `:temperature` (`t:float/0`) - Amount of randomness injected into the response.\n* `:tools` (list of `t:map/0`) - A list of tools the model may call.\n* `:top_k` (`t:integer/0`) - Only sample from the top K options for each subsequent token.\n* `:top_p` (`t:float/0`) - Amount of randomness injected into the response.","ref":"Anthropix.html#chat/2-options"},{"type":"function","title":"Message structure - Anthropix.chat/2","doc":"Each message is a map with the following fields:\n\n* `:role` (`t:String.t/0`) - Required. The role of the message, either `user` or `assistant`.\n* `:content` - Required. Message content, either a single string or an array of content blocks.","ref":"Anthropix.html#chat/2-message-structure"},{"type":"function","title":"Examples - Anthropix.chat/2","doc":"```elixir\niex> messages = [\n...>   %{role: \"user\", content: \"Why is the sky blue?\"},\n...>   %{role: \"assistant\", content: \"Due to rayleigh scattering.\"},\n...>   %{role: \"user\", content: \"How is that different than mie scattering?\"},\n...> ]\n\niex> Anthropix.chat(client, [\n...>   model: \"claude-3-opus-20240229\",\n...>   messages: messages,\n...> ])\n{:ok, %{\"content\" => [%{\n  \"type\" => \"text\",\n  \"text\" => \"Mie scattering affects all wavelengths similarly, while Rayleigh favors shorter ones.\"\n}], ...}}\n\n# Passing true to the :stream option initiates an async streaming request.\niex> Anthropix.chat(client, [\n...>   model: \"claude-3-opus-20240229\",\n...>   messages: messages,\n...>   stream: true,\n...> ])\n{:ok, #Function<52.53678557/2 in Stream.resource/3>}\n```","ref":"Anthropix.html#chat/2-examples"},{"type":"function","title":"Anthropix.init/0","doc":"Calling `init/1` without passing an API key, creates a new Anthropix API\nclient using the API key set in your application's config.\n\n```elixir\nconfig :anthropix, :api_key, \"sk-ant-your-key\"\n```\n\nIf given, a keyword list of options will be passed to `Req.new/1`.","ref":"Anthropix.html#init/0"},{"type":"function","title":"Examples - Anthropix.init/0","doc":"```elixir\niex> client = Anthropix.init()\n%Anthropix{}\n```","ref":"Anthropix.html#init/0-examples"},{"type":"function","title":"Anthropix.init/1","doc":"","ref":"Anthropix.html#init/1"},{"type":"function","title":"Anthropix.init/2","doc":"Calling `init/2` with an API key creates a new Anthropix API client, using the\ngiven API key. Optionally, a keyword list of options can be passed through to\n`Req.new/1`.","ref":"Anthropix.html#init/2"},{"type":"function","title":"Examples - Anthropix.init/2","doc":"```elixir\niex> client = Anthropix.init(\"sk-ant-your-key\", receive_timeout: :infinity)\n%Anthropix{}\n```","ref":"Anthropix.html#init/2-examples"},{"type":"type","title":"Anthropix.client/0","doc":"Client struct","ref":"Anthropix.html#t:client/0"},{"type":"type","title":"Anthropix.content_block/0","doc":"Message content block.","ref":"Anthropix.html#t:content_block/0"},{"type":"type","title":"Anthropix.content_media/0","doc":"","ref":"Anthropix.html#t:content_media/0"},{"type":"type","title":"Anthropix.content_text/0","doc":"","ref":"Anthropix.html#t:content_text/0"},{"type":"type","title":"Anthropix.content_tool_result/0","doc":"","ref":"Anthropix.html#t:content_tool_result/0"},{"type":"type","title":"Anthropix.content_tool_use/0","doc":"","ref":"Anthropix.html#t:content_tool_use/0"},{"type":"type","title":"Anthropix.input_schema/0","doc":"JSON schema for the tool `input` shape.","ref":"Anthropix.html#t:input_schema/0"},{"type":"type","title":"Anthropix.message/0","doc":"Chat message\n\nA chat message is a `t:map/0` with the following fields:\n\n* `:role` (`t:String.t/0`) - Required. The role of the message, either `user` or `assistant`.\n* `:content` - Required. Message content, either a single string or an array of content blocks.","ref":"Anthropix.html#t:message/0"},{"type":"type","title":"Anthropix.response/0","doc":"Client response","ref":"Anthropix.html#t:response/0"},{"type":"type","title":"Anthropix.tool/0","doc":"Tool.\n\nA chat tool is a `t:map/0` with the following fields:\n\n* `:name` (`t:String.t/0`) - Required. Name of the tool.\n* `:description` (`t:String.t/0`) - Required. Description of the tool\n* `:input_schema` (`t:map/0`) - Required. JSON schema for the tool input shape that the model will produce in tool_use output content blocks.","ref":"Anthropix.html#t:tool/0"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,49,46,50]}}